/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, {useContext,Component} from 'react';
import { Button } from '@material-ui/core';
import Modal from '@material-ui/core/Modal';
import Backdrop from '@material-ui/core/Backdrop';
import Zoom from '@material-ui/core/Fade';
import styled from 'styled-components'
import {Store} from '../Store.js'
import axios from 'axios'
import {apiUrl} from '../env';
import CloseIcon from '@material-ui/icons/Close';
import Profile from '../img/default_profile0.png'

const ChangeAvatarDiv = styled.div`
    color : rgba(255,255,255,.7);
    background-color:rgba(0,0,0,.5);
    position: absolute;
    bottom: 0;
    width: inherit;
    text-align: center;
    font-size: 18px;
    padding-bottom: 5px;
    font-weight: 400;
    height: 30%;
    cursor: pointer;
    display: flex;
    align-items: center;
    justify-content: center;
`


const ModalDiv = styled.div`
    background-color : #fff;
    border-radius : 4px;
    min-width : 560px;
    color : #666;
    display: flex;
    flex-direction : column;
`

const StyledButtonConfirmar = styled(Button)`
    background-color : #00acc1 !important;
    color: #fff !important;
    display: inline-block !important;
    position: relative !important;
    cursor: pointer !important;
    min-height: 36px !important;
    min-width: 88px !important;
    line-height: 36px !important;
    vertical-align: middle !important;
    align-items: center !important;
    text-align: center !important;
    border-radius: 4px !important;
    box-sizing: border-box !important;
    user-select: none !important;
    border: 0 !important;
    padding: 0 6px !important;
    margin: 6px 8px !important;
    background: transparent !important;
    background-color: transparent !important;
    color: currentColor !important;
    white-space: nowrap !important;
    text-transform: uppercase !important;
    font-weight: 500 !important;
    font-size: 14px !important;
    font-style: inherit !important;
    font-variant: inherit !important;
    font-family: inherit !important;
    text-decoration: none !important;
    overflow: hidden !important;
`

const ButtonCancelar = styled(Button)`
    outline : none !important;
    display: inline-block !important;
    position: relative !important;
    cursor: pointer !important;
    min-height: 36px !important;
    min-width: 88px !important;
    line-height: 36px !important;
    vertical-align: middle !important;
    align-items: center !important;
    text-align: center !important;
    border-radius: 3px !important;
    box-sizing: border-box !important;
    user-select: none !important;
    border: 0 !important;
    padding: 0 6px !important;
    margin: 6px 8px !important;
    background:transparent !important;
    color: currentColor !important;
    white-space: nowrap !important;
    text-transform: uppercase !important;
    font-weight: 500 !important;
    font-size: 14px !important;
    font-style: inherit !important;
    font-variant: inherit !important;
    font-family: inherit !important;
    text-decoration: none !important;
    overflow: hidden !important;
`

const ButtonsDiv = styled.div`
    display : flex;
    justify-content:flex-end;
`

const AvatarCircleDiv = styled.div`
    margin-bottom : 0;
    border-radius : 50%;
    height : 150px;
    width : 150px;
    position : relative;
`

const DivFlowHolder =styled.div`
    align-self : auto;
`

const DivAlterarFoto = styled.div`
    display : flex;
    margin-bottom : 30px;
    flex-direction : row;
    align-items : center;
    justify-content :center;
`

const DialogDiv = styled.div`
    padding : 20px 30px;
    overflow : visible !important;
`

const HeaderDiv = styled.div`
    display : flex;
    flex-direction : row;
    align-items : center;
    align-content : center;
    justify-content : center;
    max-width : 100%;
`
const StyledH2 = styled.h2`
    font-size : 26px;
    font-weight : lighter;
    margin-top : 20px;
    margin-bottom : 10px;
    font-family: inherit;
    line-height: 1.1;
    color: inherit;
`
const StyledCloseModalButton = styled(Button)`
    display : inline-block;
    position : relative;
    float : right !important;
    margin-right : -8px !important;
    background : transparent !important;
    min-width: 0 !important;
    width : 40px;
    border-radius : 50%;
    padding : 8px;
    height : 40px;
    margin : 0 6px;
`

export default function ComponentAlterarAvatar (props) {
        return (
            <ModalDiv style={{maxWidth:"500px", maxHeight:"500px"}}>
            <HeaderDiv>
                <span style={{width:"32px"}}/>
                    <StyledH2>Editar Foto</StyledH2>
                    <StyledCloseModalButton onClick={props.handleClose}>
                        <CloseIcon/>
                    </StyledCloseModalButton>
            </HeaderDiv>
            <DialogDiv>
                <div style={{marginTop:"0"}}>
                    <form>
                        <DivAlterarFoto>
                            <DivFlowHolder>
                                <AvatarCircleDiv>
                                    {
                                        props.userAvatar == '' || props.userAvatar == null ?
                                        (

                                            <img src={Profile} alt={'user avatar'} style={{height:"inherit", width:"inherit", objectFit:"cover"}}/>
                                        ):
                                        (
                                            <img src={this.props.userAvatar} alt={'user avatar'} style={{height:"inherit", width:"inherit", objectFit:"cover"}}/>
                                        )
                                    }
                                    <ChangeAvatarDiv>
                                        <span>Alterar</span>
                                        <input accept="image/*" id="icon-button-file"
                                        type="file"
                                        onChange={(e) => props.handleFile(e.target.files) }
                                        style={{display:"none"}}/>
                                    </ChangeAvatarDiv>
                                </AvatarCircleDiv>
                            </DivFlowHolder>
                        </DivAlterarFoto>
                        <ButtonsDiv>
                            <ButtonCancelar onClick={props.handleClose}><span>Cancelar</span></ButtonCancelar><StyledButtonConfirmar><span>Salvar Alterações</span></StyledButtonConfirmar>
                        </ButtonsDiv>
                    </form>
                </div>
            </DialogDiv>
            </ModalDiv>
        )

}
